Index: chrome/browser/content_settings/tab_specific_content_settings.h |
diff --git a/chrome/browser/content_settings/tab_specific_content_settings.h b/chrome/browser/content_settings/tab_specific_content_settings.h |
index 0bc6ec6c59e9008c7da71fe698b0f3ca34461b58..bc80bf9788784e586183e705f9089fd1d5d6a36e 100644 |
--- a/chrome/browser/content_settings/tab_specific_content_settings.h |
+++ b/chrome/browser/content_settings/tab_specific_content_settings.h |
@@ -83,9 +83,9 @@ class TabSpecificContentSettings |
~TabSpecificContentSettings() override; |
- // Returns the object given a render view's id. |
- static TabSpecificContentSettings* Get(int render_process_id, |
- int render_view_id); |
+ // Returns the object given a RenderFrameHost. |
+ static TabSpecificContentSettings* Get( |
+ content::RenderFrameHost* render_frame_host); |
// Static methods called on the UI threads. |
// Called when cookies for the given URL were read either from within the |